@@ -226,7 +226,7 @@ def diff():
         cont = input('\n Continue [c] or abort [Enter]? ')
         if cont == 'c':
             for doc in workTree:
-                if doc.split('/')[-1] in os.listdir('/'.join(doc.split('/')[1:-1])):
+                if doc.split('/')[-1] in os.listdir(sourceDir + '/'.join(doc.split('/')[1:-1])):
                     ProcessFiles(doc)
                 else:
                     for path in targetPaths:
